==> ui-18.0.5.tgz: package/components/table/TableSearch.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import React, { useRef } from 'react';
import { useForceUpdate } from '@react-devui/hooks';
import { SearchOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { useDValue } from '../../hooks';
import { registerComponentMate, WINDOW_SPACE } from '../../utils';
import { DButton } from '../button';
import { DInput } from '../input';
import { DPopover } from '../popover';
import { useComponentConfig, usePrefixConfig, useTranslation } from '../root';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DTable.Search' });
function TableSearch(props, ref) {
    const _a = useComponentConfig(COMPONENT_NAME, props), { dValue, dVisible, dPopupClassName, onValueChange, onVisibleChange, afterVisibleChange } = _a, restProps = __rest(_a, ["dValue", "dVisible", "dPopupClassName", "onValueChange", "onVisibleChange", "afterVisibleChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    const dataRef = useRef({
        showValue: '',
        prevValue: '',
    });
    const [t] = useTranslation();
    const forceUpdate = useForceUpdate();
    const [_value, changeValue] = useDValue('', dValue, onValueChange);
    if (_value !== dataRef.current.prevValue) {
        dataRef.current.showValue = dataRef.current.prevValue = _value;
    }
    return (_jsx(DPopover, Object.assign({ ref: ref, className: getClassName(dPopupClassName, `${dPrefix}table__filter-popup`), onClick: (e) => {
            e.stopPropagation();
        }, dVisible: dVisible, dTrigger: "click", dPlacement: "bottom-right", dArrow: false, dInWindow: WINDOW_SPACE, dContent: _jsx(DInput, { className: `${dPrefix}table__filter-search`, dModel: dataRef.current.showValue, dPrefix: _jsx(SearchOutlined, {}), dPlaceholder: t('Search'), onModelChange: (val) => {
                dataRef.current.showValue = val;
                forceUpdate();
            } }), dFooter: _jsx(DPopover.Footer, { dActions: [
                _jsx(DButton, Object.assign({ onClick: () => {
                        dataRef.current.showValue = '';
                        forceUpdate();
                    }, dType: "link" }, { children: t('Table', 'Reset') }), "$$reset"),
                'ok',
            ] }), onVisibleChange: (visible) => {
            onVisibleChange === null || onVisibleChange === void 0 ? void 0 : onVisibleChange(visible);
            if (!visible) {
                changeValue(dataRef.current.showValue);
            }
        }, afterVisibleChange: afterVisibleChange }, { children: _jsx("button", Object.assign({}, restProps, { className: getClassName(restProps.className, {
                'is-active': dataRef.current.showValue.length > 0,
            }) }, { children: _jsx(SearchOutlined, { dSize: 14 }) })) })));
}
export const DTableSearch = React.forwardRef(TableSearch);

==> ui-18.5.2.tgz: package/components/table/TableSearch.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import React, { useRef } from 'react';
import { useForceUpdate } from '@react-devui/hooks';
import { SearchOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { useDValue } from '../../hooks';
import { registerComponentMate, WINDOW_SPACE } from '../../utils';
import { DButton } from '../button';
import { DInput } from '../input';
import { DPopover } from '../popover';
import { useComponentConfig, usePrefixConfig, useTranslation } from '../root';
import { DTableThAction } from './TableThAction';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DTable.Search' });
function TableSearch(props, ref) {
    const _a = useComponentConfig(COMPONENT_NAME, props), { dValue, dVisible, dPopupClassName, onValueChange, onVisibleChange, afterVisibleChange } = _a, restProps = __rest(_a, ["dValue", "dVisible", "dPopupClassName", "onValueChange", "onVisibleChange", "afterVisibleChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    const dataRef = useRef({
        showValue: '',
        prevValue: '',
    });
    const [t] = useTranslation();
    const forceUpdate = useForceUpdate();
    const [_value, changeValue] = useDValue('', dValue, onValueChange);
    if (_value !== dataRef.current.prevValue) {
        dataRef.current.showValue = dataRef.current.prevValue = _value;
    }
    return (_jsx(DPopover, Object.assign({ ref: ref, className: getClassName(dPopupClassName, `${dPrefix}table__filter-popup`), onClick: (e) => {
            e.stopPropagation();
        }, dVisible: dVisible, dTrigger: "click", dPlacement: "bottom-right", dArrow: false, dInWindow: WINDOW_SPACE, dContent: _jsx(DInput, { className: `${dPrefix}table__filter-search`, dModel: dataRef.current.showValue, dPrefix: _jsx(SearchOutlined, {}), dPlaceholder: t('Search'), onModelChange: (val) => {
                dataRef.current.showValue = val;
                forceUpdate();
            } }), dFooter: _jsx(DPopover.Footer, { dActions: [
                _jsx(DButton, Object.assign({ onClick: () => {
                        dataRef.current.showValue = '';
                        forceUpdate();
                    }, dType: "link" }, { children: t('Table', 'Reset') }), "$$reset"),
                'ok',
            ] }), onVisibleChange: (visible) => {
            onVisibleChange === null || onVisibleChange === void 0 ? void 0 : onVisibleChange(visible);
            if (!visible) {
                changeValue(dataRef.current.showValue);
            }
        }, afterVisibleChange: afterVisibleChange }, { children: _jsx(DTableThAction, Object.assign({}, restProps, { className: getClassName(restProps.className, {
                'is-active': dataRef.current.showValue.length > 0,
            }) }, { children: _jsx(SearchOutlined, { dSize: 14 }) })) })));
}
export const DTableSearch = React.forwardRef(TableSearch);
